taika package
=============

Submodules
----------

taika.cli module
----------------

.. automodule:: taika.cli
    :members:
    :undoc-members:
    :show-inheritance:

taika.taika module
------------------

.. automodule:: taika.taika
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: taika
    :members:
    :undoc-members:
    :show-inheritance:
